@@ -36,6 +36,7 @@ OC.L10N.register(
     "List view" : "Lysaansig",
     "Actions" : "Aksies",
     "Show week numbers" : "Toon weeknommers",
+    "Update" : "Werk by",
     "Location" : "Ligging",
     "Description" : "Beskrywing",
     "Duration" : "Duur",
@@ -48,10 +49,14 @@ OC.L10N.register(
     "Friday" : "Vrydag",
     "Saturday" : "Saterdag",
     "Sunday" : "Sondag",
-    "Update" : "Werk by",
     "Your email address" : "U e-posadres",
     "Notification" : "Kennisgewing",
     "Email" : "E-pos",
+    "seconds" : "sekondes",
+    "minutes" : "minute",
+    "hours" : "uur",
+    "days" : "dae",
+    "weeks" : "weke",
     "Delete file" : "Skrap lêer",
     "Available" : "Beskikbaar",
     "Not available" : "Onbeskikbaar",
@@ -59,6 +64,8 @@ OC.L10N.register(
     "Accept" : "Aanvaar",
     "Tentative" : "Tentatief",
     "Attendees" : "Bywoners",
+    "From" : "Van",
+    "To" : "Aan",
     "All day" : "Heeldag",
     "Repeat" : "Herhaal",
     "never" : "nooit",
@@ -74,6 +81,7 @@ OC.L10N.register(
     "Week {number} of {year}" : "Week {number} van {year}",
     "Daily" : "Daagliks",
     "Weekly" : "Weekliks",
+    "second" : "sekonde",
     "Other" : "Ander",
     "Status" : "Status",
     "Confirmed" : "Bevestig",
