@@ -34,8 +34,8 @@ OC.L10N.register(
     "Next week" : "La selmana que vien",
     "Next year" : "Añu siguiente",
     "Next month" : "Mes siguiente",
-    "Event" : "Eventu",
     "Create new event" : "Crear un eventu",
+    "Event" : "Eventu",
     "Today" : "Güei",
     "Day" : "Día",
     "Week" : "Selmana",
@@ -46,29 +46,36 @@ OC.L10N.register(
     "Copy link" : "Copiar l'enllaz",
     "Edit" : "Editar",
     "Delete" : "Desaniciar",
-    "Untitled calendar" : "Calendariu ensin títulu",
-    "Edit and share calendar" : "Editar y comaprtir el calendariu",
-    "Edit calendar" : "Editar el calendariu",
     "Disable calendar \"{calendar}\"" : "Desactivar el calendariu «{calendar}»",
     "Disable untitled calendar" : "Desactivar el calendariu ensin títulu",
     "Enable calendar \"{calendar}\"" : "¿Quies activar el calendariu «{calendar}»?",
     "Enable untitled calendar" : "Activar el calendariu ensin títulu",
     "An error occurred, unable to change visibility of the calendar." : "Prodúxose un error, nun ye posible camudar la visibilidá del calendariu.",
+    "Untitled calendar" : "Calendariu ensin títulu",
+    "Edit and share calendar" : "Editar y comaprtir el calendariu",
+    "Edit calendar" : "Editar el calendariu",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Va dexar de compartise'l calendariu en {countdown} segundu","Va dexar de compartise'l calendariu en {countdown} segundos"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Va desaniciase'l calendariu en {countdown} segundu","Va desaniciase'l calendariu en {countdown} segundos"],
+    "An error occurred, unable to create the calendar." : "Prodúxose un error, nun ye posible crear el calendariu.",
     "Calendars" : "Calendarios",
     "New calendar" : "Calendariu nuevu",
     "Name for new calendar" : "Nome del calendariu nuevu",
     "Creating calendar …" : "Creando'l calendariu…",
     "Creating subscription …" : "Creando la soscripción…",
-    "An error occurred, unable to create the calendar." : "Prodúxose un error, nun ye posible crear el calendariu.",
+    "Calendar link copied to clipboard." : "L'enllaz del calendariu copióse nel cartafueyu.",
+    "Calendar link could not be copied to clipboard." : "L'enllaz del calendariu nun se pudo copiar nel cartafueyu.",
     "Copy subscription link" : "Copiar l'enllaz de soscripción",
     "Copying link …" : "Copiando l'enllaz …",
     "Copied link" : "L'enllaz copióse",
     "Could not copy link" : "Nun se pudo copiar l'enllaz",
     "Export" : "Esportar",
-    "Calendar link copied to clipboard." : "L'enllaz del calendariu copióse nel cartafueyu.",
-    "Calendar link could not be copied to clipboard." : "L'enllaz del calendariu nun se pudo copiar nel cartafueyu.",
+    "Untitled item" : "Elementu ensin nome",
+    "Unknown calendar" : "Calendariu desconocíu",
+    "Could not load deleted calendars and objects" : "Nun se pudieron desaniciar los calendarios y los oxetos",
+    "Could not delete calendar or event" : "Nun se pudo desaniciar el calendariu o l'eventu",
+    "Could not restore calendar or event" : "Nun se pudo restaurar el calendariu o l'eventu",
+    "Do you really want to empty the trash bin?" : "¿De xuru que quies balerar la papelera de reciclaxe?",
+    "Empty trash bin" : "Balerar la papelera",
     "Trash bin" : "Papelera",
     "Loading deleted items." : "Cargando los elementos desaniciaos.",
     "You do not have any deleted items." : "Nun tienes nengún elementu desaniciáu.",
@@ -76,18 +83,16 @@ OC.L10N.register(
     "Deleted" : "Desanicióse",
     "Restore" : "Restaurar",
     "Delete permanently" : "Desaniciar permanentemente",
-    "Empty trash bin" : "Balerar la papelera",
-    "Untitled item" : "Elementu ensin nome",
-    "Unknown calendar" : "Calendariu desconocíu",
-    "Could not load deleted calendars and objects" : "Nun se pudieron desaniciar los calendarios y los oxetos",
-    "Could not restore calendar or event" : "Nun se pudo restaurar el calendariu o l'eventu",
-    "Do you really want to empty the trash bin?" : "¿De xuru que quies balerar la papelera de reciclaxe?",
+    "Could not update calendar order." : "Nun se pudo anovar l'orde del calendariu.",
     "Deck" : "Tarxeteru",
     "Hidden" : "Anubrióse",
-    "Could not update calendar order." : "Nun se pudo anovar l'orde del calendariu.",
     "Internal link" : "Enllaz internu",
     "A private link that can be used with external clients" : "Un enllaz priváu que se pue usar con veceros esternos",
     "Copy internal link" : "Copiar l'enllaz internu",
+    "An error occurred, unable to publish calendar." : "Prodúxose un error, nun ye posible espublizar el calendariu.",
+    "An error occurred, unable to send email." : "Prodúxose un error, nun ye posible unviar el mensaxe.",
+    "Embed code copied to clipboard." : "El códigu incrustáu copióse nel cartafueyu.",
+    "Embed code could not be copied to clipboard." : "El códigu incrustáu nun se pudo copiar nel cartafueyu.",
     "Share link" : "Compartir l'enllaz",
     "Copy public link" : "Copiar l'enllaz públicu",
     "Send link to calendar via email" : "Unviar l'enllaz del calendariu per corréu electrónicu",
@@ -99,26 +104,21 @@ OC.L10N.register(
     "Could not copy code" : "Nun se pudo copiar el códigu",
     "Delete share link" : "Desaniciar esti enllaz d'usu compartíu",
     "Deleting share link …" : "Desaniciando l'enllaz d'usu compartíu…",
-    "An error occurred, unable to publish calendar." : "Prodúxose un error, nun ye posible espublizar el calendariu.",
-    "An error occurred, unable to send email." : "Prodúxose un error, nun ye posible unviar el mensaxe.",
-    "Embed code copied to clipboard." : "El códigu incrustáu copióse nel cartafueyu.",
-    "Embed code could not be copied to clipboard." : "El códigu incrustáu nun se pudo copiar nel cartafueyu.",
-    "Unshare with {displayName}" : "Dexar de compartir con {displayName}",
     "An error occurred while unsharing the calendar." : "Prodúxose un error mentanto se dexaba de compartir el calendariu.",
     "An error occurred, unable to change the permission of the share." : "Prodúxose un error, nun ye posible camudar el permisu del elementu compartíu.",
+    "Unshare with {displayName}" : "Dexar de compartir con {displayName}",
     "Share with users or groups" : "Compartir con usuarios o grupos",
     "No users or groups" : "Nun hai nengún usuariu nin grupu",
+    "Failed to save calendar name and color" : "Nun se pue guardar el nome y el color del calendariu",
     "Calendar name …" : "Nome del calendariu…",
     "Share calendar" : "Compartir el calendariu",
     "Save" : "Guardar",
-    "Failed to save calendar name and color" : "Nun se pue guardar el nome y el color del calendariu",
     "Import calendars" : "Importar calendarios",
     "Please select a calendar to import into …" : "Seleiciona un calendariu al qu'importar …",
     "Filename" : "Nome del ficheru",
     "Cancel" : "Encaboxar",
     "Invalid location selected" : "Seleicionóse una llocalización inválida",
     "Automatic" : "Automáticu",
-    "or" : "o",
     "Navigation" : "Navegación",
     "Previous period" : "Periodu anterior",
     "Next period" : "Periodu siguiente",
@@ -136,6 +136,12 @@ OC.L10N.register(
     "Save edited event" : "Guardar l'eventu editáu",
     "Delete edited event" : "Desaniciar l'eventu desaniciáu",
     "Duplicate event" : "Duplicar l'eventu",
+    "or" : "o",
+    "Calendar settings" : "Configuración del calendariu",
+    "No reminder" : "Nun hai nengún recordatoriu",
+    "Failed to save default calendar" : "Nun se pue guardar el calendariu predetermináu",
+    "CalDAV link copied to clipboard." : "L'enllaz CalDAV copióse nel cartafueyu.",
+    "CalDAV link could not be copied to clipboard." : "L'enllaz CalDAV nun se pudo copiar nel cartafueyu.",
     "Enable birthday calendar" : "Activar el calendariu de los cumpleaños",
     "Show tasks in calendar" : "Amosar les xeres nel calendariu",
     "Enable simplified editor" : "Activar l'editor simplificáu",
@@ -147,11 +153,6 @@ OC.L10N.register(
     "Copy iOS/macOS CalDAV address" : "Copiar la direición CalDAV d'iOS/macOS",
     "Personal availability settings" : "Configuración de la disponibilidá personal",
     "Show keyboard shortcuts" : "Amosar los atayos del tecáu",
-    "Calendar settings" : "Configuración del calendariu",
-    "No reminder" : "Nun hai nengún recordatoriu",
-    "Failed to save default calendar" : "Nun se pue guardar el calendariu predetermináu",
-    "CalDAV link copied to clipboard." : "L'enllaz CalDAV copióse nel cartafueyu.",
-    "CalDAV link could not be copied to clipboard." : "L'enllaz CalDAV nun se pudo copiar nel cartafueyu.",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minutu","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} hores"],
@@ -159,6 +160,7 @@ OC.L10N.register(
     "_{duration} week_::_{duration} weeks_" : ["{duration} selmana","{duration} selmanes"],
     "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} meses"],
     "_{duration} year_::_{duration} years_" : ["{duration} añu","{duration} años"],
+    "Update" : "Anovar",
     "Location" : "Llocalización",
     "Create a Talk room" : "Crear una sala de Talk",
     "Description" : "Descripción",
@@ -175,7 +177,6 @@ OC.L10N.register(
     "Saturday" : "Sábadu",
     "Sunday" : "Domingu",
     "Weekdays" : "Díes de la selmana",
-    "Update" : "Anovar",
     "Your email address" : "La to direición de corréu electrónicu",
     "Back" : "Atrás",
     "Notification" : "Avisu",
@@ -185,11 +186,11 @@ OC.L10N.register(
     "Edit time" : "Editar la hora",
     "Save time" : "Guardar la hora",
     "Remove reminder" : "Quitar el recordatoriu",
-    "_second_::_seconds_" : ["segundu","segundos"],
-    "_minute_::_minutes_" : ["minutu","minutos"],
-    "_hour_::_hours_" : ["hora","hores"],
-    "_day_::_days_" : ["día","díes"],
-    "_week_::_weeks_" : ["selmana","selmanes"],
+    "seconds" : "segundos",
+    "minutes" : "minutos",
+    "hours" : "Hores",
+    "days" : "díes",
+    "weeks" : "selmanes",
     "Delete file" : "Desaniciar el ficheru",
     "Confirmation" : "Confirmación",
     "Available" : "Disponible",
@@ -199,26 +200,26 @@ OC.L10N.register(
     "Awaiting response" : "Esperando pola rempuesta",
     "Checking availability" : "Comprobando la disponibilidá",
     "Has not responded to {organizerName}'s invitation yet" : "Nun respondió a la invitación de: {organizerName}",
-    "Find a time" : "Atopar una hora",
+    "Busy" : "Ocupáu",
+    "Out of office" : "Fuera de la oficina",
     "with" : "con",
     "Available times:" : "Hores disponibles:",
     "Suggestion accepted" : "Suxerencia aceptada",
     "Done" : "Fecho",
-    "Busy" : "Ocupáu",
-    "Out of office" : "Fuera de la oficina",
     "Room name" : "Nome de la sala",
-    "Accept" : "Aceptar",
-    "Decline" : "Refugar",
-    "Tentative" : "Provisional",
+    "Find a time" : "Atopar una hora",
     "The invitation has been accepted successfully." : "La invitación aceptóse correutamente.",
     "Failed to accept the invitation." : "Nun se pue aceptar la invitación",
     "The invitation has been declined successfully." : "La invitación refugóse correutamente.",
     "Failed to decline the invitation." : "Nun se pue refugar la invitación",
     "Your participation has been marked as tentative." : "La to participación marcóse como provisional.",
     "Failed to set the participation status to tentative." : "Nun se pudo afitar l'estáu de la participación a provisional",
-    "Attendees" : "Asistentes",
+    "Accept" : "Aceptar",
+    "Decline" : "Refugar",
+    "Tentative" : "Provisional",
     "No attendees yet" : "Nun hai nengún asistente",
     "Error creating Talk room" : "Hebo un error al crear la sala de Talk",
+    "Attendees" : "Asistentes",
     "_%n more guest_::_%n more guests_" : ["%n convidáu más","%n convidaos más"],
     "Remove group" : "Quitar el grupu",
     "_%n member_::_%n members_" : ["%n miembru","%n miembros"],
@@ -231,32 +232,31 @@ OC.L10N.register(
     "Repeat" : "Repitir",
     "never" : "enxamás",
     "first" : "primer",
-    "third" : "tercer",
-    "fourth" : "cuartu",
-    "fifth" : "quintu",
+    "_day_::_days_" : ["día","díes"],
+    "_week_::_weeks_" : ["selmana","selmanes"],
     "_month_::_months_" : ["mes","meses"],
     "_year_::_years_" : ["añu","años"],
     "Suggestions" : "Suxerencies",
+    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asientu","{seatingCapacity} asientos"],
     "Has a projector" : "Tien proyeutor",
     "Has a whiteboard" : "Tien pizarra",
     "Projector" : "Proyeutor",
     "Whiteboard" : "Pizarra",
-    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asientu","{seatingCapacity} asientos"],
     "More details" : "Mas detalles",
-    "Pick a date" : "Escueyi una data",
     "Please enter a valid date" : "Introduz una data válida",
+    "Pick a date" : "Escueyi una data",
     "Global" : "Global",
-    "Subscribe" : "Soscribise",
     "An error occurred, unable to read public calendars." : "Prodúxose un error, nun ye posible lleer los calendariu públicos.",
     "An error occurred, unable to subscribe to calendar." : "Prodúxose un error, nun ye posible soscribise al calendariu.",
+    "Subscribe" : "Soscribise",
     "Time:" : "Hora:",
     "Personal" : "Personal",
     "Event does not exist" : "L'eventu nun esiste",
     "Details" : "Detalles",
     "Invite" : "Convidar",
     "Resources" : "Recursos",
-    "Close" : "Zarrar",
     "Untitled event" : "Eventu ensin títulu",
+    "Close" : "Zarrar",
     "Miscellaneous" : "Miscelanea",
     "Daily" : "Caldía",
     "Weekly" : "Selmanalmente",
@@ -265,6 +265,10 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses"],
     "_Every %n year_::_Every %n years_" : ["Cada %n añu","Cada %n años"],
     "_%n time_::_%n times_" : ["%n vegada","%n vegaes"],
+    "second" : "segundu",
+    "third" : "tercer",
+    "fourth" : "cuartu",
+    "fifth" : "quintu",
     "Untitled task" : "Xera ensin títulu",
     "Please ask your administrator to enable the Tasks App." : "Pidi al alministrador qu'active l'aplicación Xeres.",
     "W" : "S",
