@@ -18,6 +18,7 @@ OC.L10N.register(
     "Save" : "Spremi",
     "Cancel" : "Odustani",
     "Actions" : "Radnje",
+    "Update" : "Ažuriraj",
     "Location" : "Lokacija",
     "Description" : "Opis",
     "to" : "do",
@@ -29,25 +30,26 @@ OC.L10N.register(
     "Friday" : "Petak",
     "Saturday" : "Subota",
     "Sunday" : "Nedjelja",
-    "Update" : "Ažuriraj",
     "Your email address" : "Vaša adresa e-pošte",
     "Email" : "E-pošta",
+    "seconds" : "sekundi",
+    "minutes" : "minuta",
+    "hours" : "sati",
+    "days" : "dana",
+    "weeks" : "sedmica",
     "Busy" : "Zauzet",
     "Unknown" : "Nepoznato",
     "Accept" : "Prihvati",
     "Decline" : "Odbij",
-    "Send email" : "Pošalji e-poštu",
+    "Attendees" : "Sudionici",
     "Repeat" : "Ponovi",
     "never" : "nikad",
-    "More" : "Više",
     "Personal" : "Osobno",
-    "Attendees" : "Sudionici",
     "Close" : "Zatvori",
     "Daily" : "Dnevno",
     "Weekly" : "Sedmično",
+    "second" : "drugi",
     "Other" : "Ostali",
-    "Status" : "Status",
-    "Mail" : "E-Pošta",
-    "Birthday" : "Rođendan"
+    "Status" : "Status"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
